pub struct EmailPlugin { /* private fields */ }Expand description
Email transport plugin. Sends emails via SMTP or logs them in dev mode.
Implementations
Sourceimpl EmailPlugin
impl EmailPlugin
Sourcepub fn new(transport: EmailTransport) -> Self
pub fn new(transport: EmailTransport) -> Self
Create a new email plugin with the given transport.
Sourcepub fn send(&self, msg: EmailMessage) -> Result<(), String>
pub fn send(&self, msg: EmailMessage) -> Result<(), String>
Send an email via the configured transport.
Sourcepub fn sent_history(&self) -> Vec<SentEmail>
pub fn sent_history(&self) -> Vec<SentEmail>
Return the history of all emails sent through this plugin.