Structs
- Soft
Delete Plugin - Soft delete plugin. Converts deletes to updates that set
deletedAt. Adds a before_delete hook that rejects the actual delete and instead sets a timestamp. The application should filter out soft-deleted rows.
deletedAt.
Adds a before_delete hook that rejects the actual delete and instead
sets a timestamp. The application should filter out soft-deleted rows.